@@ -143,7 +143,7 @@ class WindowBackingBase(object):
         if not self._alpha_enabled:
             target_rgb_modes = [x for x in target_rgb_modes if x.find("A")<0]
         full_csc_modes = getVideoHelper().get_server_full_csc_modes_for_rgb(*target_rgb_modes)
-        log("full csc modes (%s)=%s", target_rgb_modes, full_csc_modes)
+        log("_get_full_csc_modes(%s)=%s (target_rgb_modes=%s)", rgb_modes, full_csc_modes, target_rgb_modes)
         return full_csc_modes
 
     def _get_csc_modes(self, rgb_modes):
@@ -161,15 +161,11 @@ class WindowBackingBase(object):
         return img_data
 
     def unpremultiply(self, img_data):
-        if type(img_data)==str:
-            #cannot do in-place:
-            assert unpremultiply_argb is not None, "missing argb.unpremultiply_argb"
+        try:
+            unpremultiply_argb_in_place(img_data)
+            return img_data
+        except:
             return byte_buffer_to_buffer(unpremultiply_argb(img_data))
-        #assume this is a writeable buffer (ie: ctypes from mmap):
-        assert unpremultiply_argb_in_place is not None, "missing argb.unpremultiply_argb_in_place"
-        unpremultiply_argb_in_place(img_data)
-        return img_data
-
 
     def process_delta(self, raw_data, width, height, rowstride, options):
         """
@@ -255,13 +251,14 @@ class WindowBackingBase(object):
     def paint_webp(self, img_data, x, y, width, height, options, callbacks):
         dec_webp = get_codec("dec_webp")
         has_alpha = options.get("has_alpha", False)
-        buffer_wrapper, width, height, stride, has_alpha, rgb_format = dec_webp.decompress(img_data, has_alpha)
+        buffer_wrapper, width, height, stride, has_alpha, rgb_format = dec_webp.decompress(img_data, has_alpha, options.get("rgb_format"))
+        #replace with the actual rgb format we get from the decoder:
         options["rgb_format"] = rgb_format
         def free_buffer(*args):
             buffer_wrapper.free()
         callbacks.append(free_buffer)
         data = buffer_wrapper.get_pixels()
-        if has_alpha:
+        if len(rgb_format)==4:
             return self.paint_rgb32(data, x, y, width, height, stride, options, callbacks)
         else:
             return self.paint_rgb24(data, x, y, width, height, stride, options, callbacks)
