@@ -4,21 +4,28 @@
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
+import time
 import sys
 import os
 import errno
 import socket
 
+from xpra.log import Logger
+log = Logger("network", "protocol")
+
 #on some platforms (ie: OpenBSD), reading and writing from sockets
 #raises an IOError but we should continue if the error code is EINTR
 #this wrapper takes care of it.
-CONTINUE = [errno.EINTR]
-ABORT = [errno.ECONNRESET, errno.EPIPE]
+CONTINUE = {errno.EINTR : "EINTR"}
+ABORT = {
+    errno.ECONNRESET    : "ECONNRESET",
+    errno.EPIPE         : "EPIPE"}
+continue_wait = 0
 if sys.platform.startswith("win"):
     #on win32, we have to deal with a few more odd error codes:
     #(it would be nicer if those were wrapped using errno instead..)
     WSAEWOULDBLOCK = 10035
-    CONTINUE.append(WSAEWOULDBLOCK)
+    CONTINUE[WSAEWOULDBLOCK] = "WSAEWOULDBLOCK"
 
     #some of these may be redundant or impossible to hit? (does not hurt I think)
     WSAENETDOWN     = 10050
@@ -27,19 +34,37 @@ if sys.platform.startswith("win"):
     WSAECONNRESET   = 10054
     WSAENOTCONN     = 10057
     WSAESHUTDOWN    = 10058
-    ABORT += [WSAECONNABORTED, WSAECONNRESET, WSAENETDOWN,
-              WSAENETUNREACH, WSAENOTCONN, WSAENOTCONN]
+    ABORT.update({
+        WSAECONNABORTED     : "WSAECONNABORTED",
+        WSAECONNRESET       : "WSAECONNRESET",
+        WSAENETDOWN         : "WSAENETDOWN",
+        WSAENETUNREACH      : "WSAENETUNREACH",
+        WSAENOTCONN         : "WSAENOTCONN",
+        WSAESHUTDOWN        : "WSAESHUTDOWN",
+        })
+    #on win32, we want to wait just a little while,
+    #to prevent servers spinning wildly on non-blocking sockets:
+    continue_wait = 5
 
 
 def untilConcludes(is_active_cb, f, *a, **kw):
+    wait = continue_wait
     while is_active_cb():
         try:
             return f(*a, **kw)
-        except socket.timeout:
+        except socket.timeout as e:
+            log("untilConcludes(%s, %s, %s, %s) %s", is_active_cb, f, a, kw, e)
             continue
-        except (IOError, OSError), e:
-            if e.args[0] in CONTINUE:
+        except (IOError, OSError) as e:
+            code = e.args[0]
+            can_continue = CONTINUE.get(code)
+            if can_continue:
+                log("untilConcludes(%s, %s, %s, %s) %s / %s (continue)", is_active_cb, f, a, kw, can_continue, e)
+                time.sleep(wait/1000.0)     #wait is in milliseconds, sleep takes seconds
+                if wait<continue_wait:
+                    wait += 1
                 continue
+            log("untilConcludes(%s, %s, %s, %s) %s / %s (raised)", is_active_cb, f, a, kw, ABORT.get(code, code), e)
             raise
 
 
