@@ -268,25 +268,23 @@ def do_parse_cmdline(cmdline, defaults):
                           usage="\n" + "".join(command_options))
     hidden_options = {"display" : defaults.display,
                       "displayfd" : defaults.displayfd}
-    if len(server_modes):
-        group = optparse.OptionGroup(parser, "Server Options",
-                    "These options are only relevant on the server when using the %s mode." %
-                    " or ".join(["'%s'" % x for x in server_modes]))
-        parser.add_option_group(group)
+    group = optparse.OptionGroup(parser, "Server Options",
+                "These options are only relevant on the server when using the %s mode." %
+                " or ".join(["'%s'" % x for x in server_modes]))
+    parser.add_option_group(group)
+    #we support remote start, so we need those even if we don't have server support:
+    group.add_option("--start-child", action="append",
+                      dest="start_child", metavar="CMD", default=list(defaults.start_child or []),
+                      help="program to spawn in new server (may be repeated) (default: %default)")
+    group.add_option("--exit-with-children", action="store_true",
+                      dest="exit_with_children", default=defaults.exit_with_children,
+                      help="Terminate server when --start-child command(s) exit")
     if supports_server:
-        group.add_option("--start-child", action="append",
-                          dest="start_child", metavar="CMD", default=list(defaults.start_child or []),
-                          help="program to spawn in new server (may be repeated) (default: %default)")
-        group.add_option("--exit-with-children", action="store_true",
-                          dest="exit_with_children", default=defaults.exit_with_children,
-                          help="Terminate server when --start-child command(s) exit")
         group.add_option("--tcp-proxy", action="store",
                           dest="tcp_proxy", default=defaults.tcp_proxy,
                           metavar="HOST:PORT",
                           help="The address to which non-xpra packets will be forwarded.")
     else:
-        hidden_options["start_child"] = None
-        hidden_options["exit_with_children"] = False
         hidden_options["tcp_proxy"] = ""
     if (supports_server or supports_shadow) and CAN_DAEMONIZE:
         group.add_option("--no-daemon", action="store_false",
@@ -386,7 +384,7 @@ def do_parse_cmdline(cmdline, defaults):
                       help="Disable forwarding of system notifications (default: %s)" % enabled_str(defaults.notifications))
     group.add_option("--system-tray", action="store_true",
                       dest="system_tray", default=defaults.system_tray,
-                      help="Disable forwarding of system tray icons (default: %s)" % enabled_str(defaults.system_tray))
+                      help="Enable forwarding of system tray icons (default: %s)" % enabled_str(defaults.system_tray))
     group.add_option("--no-system-tray", action="store_false",
                       dest="system_tray", default=defaults.system_tray,
                       help="Disable forwarding of system tray icons (default: %s)" % enabled_str(defaults.system_tray))
@@ -834,19 +832,37 @@ def parse_display_name(error_cb, opts, display_name):
                 desc["username"] = username
                 opts.username = username
                 full_ssh += ["-l", username]
-        upos = host.find(":")
-        if upos>0:
-            port = host[upos+1:]
+        upos = host.rfind(":")
+        ssh_port = ""
+        if host.count(":")>=2:
+            #more than 2 ":", assume this is IPv6:
+            if host.startswith("["):
+                #if we have brackets, we can support: "[HOST]:SSHPORT"
+                epos = host.find("]")
+                if epos<0:
+                    error_cb("invalid host format, expected IPv6 [..]")
+                ssh_port = host[epos+1:]            #ie: ":SSHPORT"
+                if ssh_port.startswith(":"):
+                    ssh_port = ssh_port[1:]         #ie: "SSHPORT"
+                host = host[1:epos]                 #ie: "HOST"
+            else:
+                #otherwise, we have to assume they are all part of IPv6
+                #we could count them at split at 8, but that would be just too fugly
+                pass
+        elif upos>0:
+            #assume HOST:SSHPORT
+            ssh_port = host[upos+1:]
             host = host[:upos]
+        if ssh_port:
             try:
-                desc["port"] = int(port)
+                desc["port"] = int(ssh_port)
             except:
-                error_cb("invalid ssh port specified: %s", port)
+                error_cb("invalid ssh port specified: %s" % ssh_port)
             #grr why bother doing it different?
             if is_putty:
-                full_ssh += ["-P", port]
+                full_ssh += ["-P", ssh_port]
             else:
-                full_ssh += ["-p", port]
+                full_ssh += ["-p", ssh_port]
 
         full_ssh += ["-T", host]
         desc["host"] = host
@@ -959,7 +975,7 @@ def connect_to(display_desc, debug_cb=None, ssh_fail_cb=ssh_connect_failed):
     if dtype == "ssh":
         cmd = display_desc["full_ssh"]
         proxy_cmd = display_desc["remote_xpra"] + display_desc["proxy_command"] + display_desc["display_as_args"]
-        cmd += ["sh -c 'xpra initenv >> /dev/null 2>&1 || echo \"Warning: xpra server does not support initenv\" 1>&2;"+(" ".join(proxy_cmd))+"'"]
+        cmd += ["xpra initenv >> /dev/null 2>&1 || echo \"Warning: xpra server does not support initenv\" 1>&2;"+(" ".join(proxy_cmd))]
         try:
             kwargs = {}
             kwargs["stderr"] = sys.stderr
@@ -1090,6 +1106,8 @@ def run_client(error_cb, opts, extra_args, mode):
         from xpra.client.gobject_client_base import DetachXpraClient
         app = DetachXpraClient(connect(), opts)
     else:
+        from xpra.platform.gui import init as gui_init
+        gui_init()
         app = make_client(error_cb, opts)
         layouts = app.get_supported_window_layouts() or ["default"]
         layouts_str = ", ".join(layouts)
@@ -1168,7 +1186,7 @@ def do_run_client(app):
         app.cleanup()
 
 def shellquote(s):
-    return "'" + s.replace("'", "'\\''") + "'"
+    return '"' + s.replace('"', '\\"') + '"'
 
 def strip_defaults_start_child(start_child, defaults_start_child):
     if start_child and defaults_start_child:
