@@ -456,7 +456,7 @@ class ServerSource(object):
             ws = self.window_sources.get(wid)
             if ws:
                 ws.resume(window)
-        self.do_send_cursor()
+        #self.do_send_cursor()
 
 
     def user_event(self):
@@ -1356,7 +1356,7 @@ class ServerSource(object):
         if not self.can_send_window(window):
             return
         if prop=="icon" and self.raw_window_icons:
-            self.send_window_icon(window, wid)
+            self.send_window_icon(wid, window)
         else:
             metadata = self._make_metadata(wid, window, prop)
             if len(metadata)>0:
